

.. _l-HISTORY:

=======
History
=======

current - 2020-10-12 - 0.00Mb
=============================

* `37`: Replace mpl_finance by mplfinance (2020-10-11)
* `36`: Removes dependency on colormap (2020-08-08)
* `35`: Add helpers to draw maps of France (2020-05-09)

1.3.839 - 2020-04-24 - 0.45Mb
=============================

* `34`: Extend the list of dependencies (2020-04-24)
* `32`: Cannot run due to import error (2020-04-24)
* `33`: Failure when updating to pandas 1.0 (2020-02-02)

1.3.825 - 2019-09-20 - 0.45Mb
=============================

* `31`: Remove strong dependency on qgrid (2019-09-19)
* `30`: add a None ordered parameter (2019-09-19)
* `29`: StockPrice fails with pandas 0.24 (2019-02-02)
* `28`: Python 2 vs Python 3 (2019-02-02)
* `26`: update default antlr4 version to 4.7.1 (2018-10-25)
* `25`: update CSharp grammar (2018-10-25)
* `21`: remove underscores in subfolders (2018-07-31)
* `24`: fix download_data when url is a list or urls (2018-06-16)
* `23`: fix add_missing_indices failing due to more strict comparisons in pandas 0.23 (2018-05-21)
* `19`: velib collection, group files instead of having multiple files (moved to maydataapi) (2018-05-21)
* `22`: move pandas_groupby_nan to pandas_streaming (2018-05-17)
* `20`: move access to API to manydataapi (2018-05-05)
* `18`: fix urls to download data (google, yahoo) (2018-03-16)
* `17`: update candle plot for finance (matplotlib.finance was removed in 2.2.0) (2018-03-10)
* `15`: StockPrices: start and end date are not taking into account with the default data provider (2017-09-17)
* `14`: StockPrices: switch to google as default data provider (2017-09-17)
* `13`: add a class TableFormula as an example to extend pandas dataframe (2017-09-03)
* `11`: create graph image with blockdiag (2017-08-18)
* `10`: fix download_data (2017-08-12)
* `9`: Finance (2017-08-05)
* `5`: allow to submit a hive job on HDInsight from a notebook (2017-02-25)
* `6`: fix appveyor build (2016-06-22)
* `4`: use pyquickhelper magic parser to interpret python variable for azure magic commands (2016-05-14)
